/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 Module:       FGFDMExecNET.cpp
 Author:       Lorne McIntosh
 Date started: 2007/07/31
 Purpose:      A managed wrapper for FGFDMExec

--------- Copyright (C) 2007  Lorne D. McIntosh (lorne@lorneswork.com) ---------

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

HISTORY
--------------------------------------------------------------------------------
2007/07/31   LDM   Created

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/

#include "FGFDMExecNET.h"

using namespace StringUtilities;

namespace JSBSimNET
{
	FGFDMExecNET::FGFDMExecNET()
	{
		jsbsim = new JSBSim::FGFDMExec();
	}

	FGFDMExecNET::~FGFDMExecNET()
	{
		if (jsbsim != NULL)
		delete jsbsim;
	}

	bool FGFDMExecNET::Run(void)
	{
		return jsbsim->Run();
	}

	bool FGFDMExecNET::RunIC(void)
	{
		return jsbsim->RunIC();
	}

	bool FGFDMExecNET::LoadModel(String^ AircraftPath, String^ EnginePath, String^ model, bool addModelToPath)
	{
		return jsbsim->LoadModel(
			StringConverter(AircraftPath).STLAnsiString,
			StringConverter(EnginePath).STLAnsiString,
			StringConverter(model).STLAnsiString,
			addModelToPath
			);
	}

	bool FGFDMExecNET::LoadModel(String^ AircraftPath, String^ EnginePath, String^ model)
	{
		return LoadModel(AircraftPath, EnginePath, model, true);
	}

	bool FGFDMExecNET::LoadModel(String^ model, bool addModelToPath)
	{
		return jsbsim->LoadModel(StringConverter(model).STLAnsiString, addModelToPath);
	}
	bool FGFDMExecNET::LoadModel(String^ model)
	{
		return LoadModel(model, true);
	}
	
	bool FGFDMExecNET::LoadScript(String^ Script)
	{
		return jsbsim->LoadScript(StringConverter(Script).STLAnsiString);
	}

	bool FGFDMExecNET::LoadIC(String^ rstname, bool useStoredPath)
	{
		return jsbsim->GetIC()->Load(StringConverter(rstname).STLAnsiString, useStoredPath);
	}

	bool FGFDMExecNET::LoadIC(String^ rstname)
	{
		return LoadIC(rstname, true);
	}

	void FGFDMExecNET::DoTrim(int mode)
	{
		jsbsim->DoTrim(mode);
	}

	void FGFDMExecNET::DisableOutput(void)
	{
		jsbsim->DisableOutput();
	}

	void FGFDMExecNET::EnableOutput(void)
	{
		jsbsim->EnableOutput();
	}

	void FGFDMExecNET::Hold(void)
	{
		jsbsim->Hold();
	}

	void FGFDMExecNET::Resume(void)
	{
		jsbsim->Resume();
	}

	bool FGFDMExecNET::Holding(void)
	{
		return jsbsim->Holding();
	}

	void FGFDMExecNET::SuspendIntegration(void)
	{
		jsbsim->GetState()->SuspendIntegration();
	}

	void FGFDMExecNET::ResumeIntegration(void)
	{
		jsbsim->GetState()->ResumeIntegration();
	}

	bool FGFDMExecNET::IntegrationSuspended(void)
	{
		return jsbsim->GetState()->IntegrationSuspended();
	}

	void FGFDMExecNET::SetDebugLevel(int level)
	{
		jsbsim->SetDebugLevel(level);
	}

	double FGFDMExecNET::GetPropertyValue(String^ propertyName)
	{
		return jsbsim->GetPropertyValue(StringConverter(propertyName).STLAnsiString);
	}

	bool FGFDMExecNET::SetPropertyValue(String^ propertyName, double value)
	{
		jsbsim->SetPropertyValue(StringConverter(propertyName).STLAnsiString, value);
		return true;
	}

	String^ FGFDMExecNET::EnginePath::get()
	{
		return StringConverter(jsbsim->GetEnginePath()).operator System::String^();
	}

	void FGFDMExecNET::EnginePath::set(String^ EnginePath)
	{
		jsbsim->SetEnginePath(StringConverter(EnginePath).STLAnsiString);
	}

	String^ FGFDMExecNET::AircraftPath::get()
	{
		return StringConverter(jsbsim->GetAircraftPath()).operator System::String^();
	}

	void FGFDMExecNET::AircraftPath::set(String^ AircraftPath)
	{
		jsbsim->SetAircraftPath(StringConverter(AircraftPath).STLAnsiString);
	}

	String^ FGFDMExecNET::FullAircraftPath::get()
	{
		return StringConverter(jsbsim->GetFullAircraftPath()).operator System::String^();
	}

	String^ FGFDMExecNET::ModelName::get()
	{
		return StringConverter(jsbsim->GetModelName()).operator System::String^();
	}

	double FGFDMExecNET::SimTime::get()
	{
		return jsbsim->GetSimTime();
	}

	double FGFDMExecNET::DeltaT::get()
	{
		return jsbsim->GetDeltaT();
	}
}