/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 Module:       TextBoxTextWriterTraceListener.cs
 Author:       Lorne McIntosh
 Date started: 2007/07/31
 Purpose:      A TraceListener that appends to a TextBox

--------- Copyright (C) 2007  Lorne D. McIntosh (lorne@lorneswork.com) ---------

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

HISTORY
--------------------------------------------------------------------------------
2007/07/31   LDM   Created

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace JSBSimTest
{
    public class TextBoxTextWriterTraceListener : TextWriterTraceListener
    {
        private TextBox _textBox;
        private delegate void MyDelegate(string arg);

        public TextBoxTextWriterTraceListener(TextBox textBox) : base()
        {
            _textBox = textBox;
        }

        public override void Write(string value)
        {
            if (_textBox.InvokeRequired)
            {
                _textBox.BeginInvoke(new MyDelegate(_Write), new object[] { value });
            }
            else
            {
                _Write(value);
            }
        }

        public override void WriteLine(string value)
        {
            if (_textBox.InvokeRequired)
            {
                _textBox.BeginInvoke(new MyDelegate(_WriteLine), new object[] { value });
            }
            else
            {
                _Write(value);
            }
        }

        private void _Write(string value)
        {
            _textBox.AppendText(value);
        }

        private void _WriteLine(string value)
        {
            _Write(value);
            _textBox.AppendText(Environment.NewLine);
        }
    }
}